==================================
 Mockstar -- mock like a rockstar
==================================

Mockstar is a lightweight library on top of
`http://www.voidspace.org.uk/python/mock/ <mock>`_ library that was
written because I hate copypaste.

If you are a honest man that tries to cover all his code with 100% of
tests, then you know that you will have tons and tons of tests. That's
why it is important to reduce lines of code and repeating yourself
when you write those.

Documentation: `http://mockstar.readthedocs.org
<http://mockstar.readthedocs.org>`_.
